@@ -5,7 +5,6 @@
   (enumerator_list)
   (parameter_list)
   (init_declarator)
-  (case_statement)
   (expression_statement)
 ] @indent
 
@@ -13,6 +12,7 @@
   "case"
   "}"
   "]"
+  ")"
 ] @outdent
 
 (if_statement
@@ -32,3 +32,7 @@
   (_) @indent
   (#not-kind-eq? @indent "compound_statement")
   (#set! "scope" "all"))
+
+(parameter_list
+  . (parameter_declaration) @anchor
+  (#set! "scope" "tail")) @align
