@@ -4,6 +4,16 @@
   (raw_text) @injection.content)
   (#set! injection.language "css"))
 
+((style_element
+    (start_tag
+      (attribute
+        (attribute_name) @_attr
+        (quoted_attribute_value (attribute_value) @_lang)))
+    (raw_text) @injection.content)
+  (#eq? @_attr "lang")
+  (#match? @_lang "scss")
+  (#set! injection.language "scss"))
+
 ((attribute
    (attribute_name) @_attr
    (quoted_attribute_value (attribute_value) @css))
